==> vows_0.5.8+20110312.orig.tar.gz: vows-0.5.8+20110312/lib/vows/reporters/dot-matrix.js <==

var sys = require('sys');

var options = {};
var console = require('vows/console');
var spec = require('vows/reporters/spec');
var stylize = console.stylize,
    puts = console.puts(options);
//
// Console reporter
//
var stream, messages = [], lastContext;

this.name = 'dot-matrix';
this.reset = function () {
    messages = [];
    lastContext = null;
};
this.report = function (data, s) {
    var event = data[1];

    options.stream = typeof(s) === 'object' ? s : process.stdout;

    switch (data[0]) {
        case 'subject':
            // messages.push(stylize(event, 'underline') + '\n');
            break;
        case 'context':
            break;
        case 'vow':
            if (event.status === 'honored') {
                sys.print(stylize('·', 'green'));
            } else if (event.status === 'pending') {
                sys.print(stylize('-', 'cyan'));
            } else {
                if (lastContext !== event.context) {
                    lastContext = event.context;
                    messages.push(spec.contextText(event.context));
                }
                if (event.status === 'broken') {
                    sys.print(stylize('✗', 'yellow'));
                    messages.push(spec.vowText(event));
                } else if (event.status === 'errored') {
                    sys.print(stylize('✗', 'red'));
                    messages.push(spec.vowText(event));
                }
                messages.push('');
            }
            break;
        case 'end':
            sys.print(' ');
            break;
        case 'finish':
            if (messages.length) {
                puts('\n\n' + messages.join('\n'));
            } else {
                sys.print('\n');
            }
            puts(console.result(event).join('\n'));
            break;
        case 'error':
            puts(console.error(event));
            break;
    }
};

this.print = function (str) {
    sys.print(str);
};

==> vows_0.8.3.orig.tar.gz: vows-0.8.3/lib/vows/reporters/dot-matrix.js <==
var options = { tail: '' },
    console = require('../../vows/console'),
    stylize = console.stylize,
    puts = console.puts(options);
//
// Console reporter
//
var messages = [], lastContext;

this.name = 'dot-matrix';
this.setStream = function (s) {
    options.stream = s;
};

this.reset = function () {
    messages = [];
    lastContext = null;
};
this.report = function (data) {
    var event = data[1];

    switch (data[0]) {
        case 'subject':
            // messages.push(stylize(event, 'underline') + '\n');
            break;
        case 'context':
            break;
        case 'vow':
            if (event.status === 'honored') {
                puts(stylize('·', 'green'));
            } else if (event.status === 'pending') {
                puts(stylize('-', 'cyan'));
            } else {
                if (lastContext !== event.context) {
                    lastContext = event.context;
                    messages.push('  ' + event.context);
                }
                if (event.status === 'broken') {
                    puts(stylize('✗', 'yellow'));
                    messages.push(console.vowText(event));
                } else if (event.status === 'errored') {
                    puts(stylize('✗', 'red'));
                    messages.push(console.vowText(event));
                }
                messages.push('');
            }
            break;
        case 'end':
            puts(' ');
            break;
        case 'finish':
            if (messages.length) {
                puts('\n\n' + messages.join('\n'));
            } else {
                puts('');
            }
            puts(console.result(event).join('\n'));
            break;
        case 'error':
            puts(console.error(event));
            break;
    }
};

this.print = function (str) {
    puts(str);
};
